package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SysSmsLog;

/**
 * 短信发送记录Service接口
 * 
 * @author ruoyi
 * @date 2025-09-12
 */
public interface ISysSmsLogService 
{
    /**
     * 查询短信发送记录
     * 
     * @param id 短信发送记录主键
     * @return 短信发送记录
     */
    public SysSmsLog selectSysSmsLogById(Long id);

    /**
     * 查询短信发送记录列表
     * 
     * @param sysSmsLog 短信发送记录
     * @return 短信发送记录集合
     */
    public List<SysSmsLog> selectSysSmsLogList(SysSmsLog sysSmsLog);

    /**
     * 新增短信发送记录
     * 
     * @param sysSmsLog 短信发送记录
     * @return 结果
     */
    public int insertSysSmsLog(SysSmsLog sysSmsLog);

    /**
     * 修改短信发送记录
     * 
     * @param sysSmsLog 短信发送记录
     * @return 结果
     */
    public int updateSysSmsLog(SysSmsLog sysSmsLog);

    /**
     * 批量删除短信发送记录
     * 
     * @param ids 需要删除的短信发送记录主键集合
     * @return 结果
     */
    public int deleteSysSmsLogByIds(Long[] ids);

    /**
     * 删除短信发送记录信息
     * 
     * @param id 短信发送记录主键
     * @return 结果
     */
    public int deleteSysSmsLogById(Long id);
}
